@@ -106,7 +106,7 @@ class InsertMendoza:
 
     def AccountView(self):
         return self.Request(url='accounts/accounts', method=GET, data={})
-    
+
     def ManagerView(self):
         return self.Request(url='managers', method=GET, data={})
 
@@ -121,7 +121,6 @@ class InsertMendoza:
     def ManagerDelete(self, uuid, data):
         return self.Request(url=f'managers/{uuid}', method=DELETE, data=data)
 
-    
     def BiometricView(self):
         return self.Request(url='biometrics/biometrics', method=GET, data={})
 
@@ -134,7 +133,6 @@ class InsertMendoza:
     def BiometricDelete(self, uuid, data):
         return self.Request(url=f'biometrics/biometrics/{uuid}', method=DELETE, data=data)
 
-
     def MemoryView(self):
         return self.Request(url='biometrics/memories', method=GET, data={})
 
@@ -147,7 +145,6 @@ class InsertMendoza:
     def MemoryDelete(self, uuid, data):
         return self.Request(url=f'biometrics/memories/{uuid}', method=DELETE, data=data)
 
-    
     def CustomersView(self):
         return self.Request(url='customers', method=GET, data={})
 
@@ -162,17 +159,24 @@ class InsertMendoza:
     def CustomersDelete(self, uuid, data):
         return self.Request(url=f'customers/{uuid}', method=DELETE, data=data)
 
-    
     def EmployeeAdd(self, phone, first_name, last_name):
         return self.Request(url='employee', method=POST, data={
             'phone': phone, 'first_name': first_name, 'last_name': last_name,
         })
 
     def EmployeeView(self):
-        return self.Request(url='employee', method=GET, data={}) 
+        return self.Request(url='employee', method=GET, data={})
 
     def EmployeeUpdate(self, uuid, data):
         return self.Request(url=f'employee/{uuid}', method=PUT, data=data)
 
     def EmployeeDelete(self, uuid, data):
-        return self.Request(url=f'custoemployeemers/{uuid}', method=DELETE, data=data)
\ No newline at end of file
+        return self.Request(url=f'employee/{uuid}', method=DELETE, data=data)
+
+    def CameraAdd(self, username, password, ip, port, endpoint='/h264/ch1/main/av_stream'):
+        return self.Request(url=f'streaming/camera', method=POST, data={
+            'username': username, 'password': password, 'ip': ip, 'port': port, 'endpoint': endpoint
+        })
+
+    def DeviceAdd(self, user):
+        return self.Request(url=f'streaming/device', method=POST, data={'user': user})
